@@ -42,7 +42,7 @@ val7 25 --> 15, 2019,05,29
 val6 15 --> 5
 val3 24 --> 14
 ovun4 7 --> 5
-ovun8 9-->3
+ovun8 9-->3   2.89 --> 1.89
 tor3 16 --> 14
 tor2 18 --> 2
 tor4 20 --> 2
