@@ -8,7 +8,7 @@ if __name__ == '__main__':
    SinglePointEnergies('md.traj',label='h2o-s3',
                        xcf='GGA',
                        xca='PBE',
-                       basistype='split'
+                       basistype='split',
                        frame=50,cpu=4)
 
 
